@@ -3,10 +3,10 @@ package WebService::MinFraud::Record::Device;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '1.004000';
+our $VERSION = '1.005000';
 
 use Types::UUID;
-use WebService::MinFraud::Types qw( Num Str );
+use WebService::MinFraud::Types qw( NonNegativeNum Num Str );
 
 has confidence => (
     is        => 'ro',
@@ -42,7 +42,7 @@ WebService::MinFraud::Record::Device - Contains data for the device associated w
 
 =head1 VERSION
 
-version 1.004000
+version 1.005000
 
 =head1 SYNOPSIS
 
@@ -86,6 +86,18 @@ This is the date and time of the last sighting of the device on the specified
 IP address for your user account. The string is formatted in the ISO 8601
 combined date and time in UTC.
 
+=head2 session_age
+
+A floating point number. The number of seconds between the creation of the
+user's session and the time of the transaction. Note that C<session_age> is not
+the duration of the current visit, but the time since the start of the first
+visit.
+
+=head2 session_id
+
+A string up to 255 characters in length. This is an ID which uniquely
+identifies a visitor's session on the site.
+
 =head1 PREDICATE METHODS
 
 The following predicate methods are available, which return true if the related
@@ -97,6 +109,10 @@ data was present in the response body, false if otherwise:
 
 =head2 has_last_seen
 
+=head2 has_session_age
+
+=head2 has_session_id
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
